Components › Statistic — Stisla

# Statistic

## Statistics

The chat component and is equipped with a JavaScript API, making it easy for you to integrate with Back-end.

#### Summary

Chart Text

#### $1,858

Sold 4 items on 2 customers
View All

###### Item List (4 Items)

- $805
  iBook Noob
  by Ahmad Sutisna
  Sunday
- $405
  Headphone Blitz
  by Hasan Basri
  Sunday
- $499
  RocketZ
  by Hasan Basri
  Sunday
- $149
  Xiaomay Readme 4.0
  by Kusnaedi
  Tuesday

#### Statistics

Week Month Year
7%
$243
Today
23%
$2,902
This Week
9%
$12,821
This Month
19%
$92,142
This Year

#### Popular Browser

Chrome
48%
Firefox
26%
Safari
14%
Opera
7%
IE
5%

#### Visitors

Indonesia
8,400
Palestine
7,328
Syiria
5,830
Malaysia
4,763

#### Referral URL

558
Google
338
Facebook
238
Bing
190
Yahoo